@@ -150,6 +150,27 @@ def get_TAs_from_csv(csv_row):
   Output: returns the list of signed TAs.
   """
   return csv_row[len(SIGNUP_SHEET_HEADER):]
+def filter_events_by_TA(ta_id, csv_rows):
+  """
+  Input: ta_id is the string to (exactly) match the TAs' identifiers against;
+  csv_rows is a list of CSV rows, as from csv.reader.
+
+  Output: a list of CSV rows containing only the rows containing ta_id.
+  """
+  return list(filter(
+    lambda x: ta_id in get_TAs_from_csv(x),
+    csv_rows))
+def filter_events_by_title(event_title, csv_rows):
+  """
+  Input: event_title is the substring to match the event title against;
+  csv_rows is a list of CSV rows, as from csv.reader.
+
+  Output: a list of CSV rows containing only the rows with an event title 
+  having event_title as substring.
+  """
+  return list(filter(
+    lambda x: event_title in x[SIGNUP_SHEET_HEADER.index("Event")],
+    csv_rows))
 def hours_per_student(csv_rows):
   """
   Input: The schedule as rows of CSV data as from csv.reader.
@@ -243,6 +264,30 @@ def max_hours(csv_rows):
     max_hours += time * max_num_TAs
 
   return max_hours
+def hours_per_event(csv_rows):
+  """
+  Input: Rows of CSV data as from csv.reader.
+
+  Output: a dictionary mapping an event type to the number of hours assigned to 
+  that type of event in the sign-up sheet, {event: hours}. The hours as 
+  datetime.timedelta objects.
+  """
+  event_hours = {}
+
+  start_index = SIGNUP_SHEET_HEADER.index("Start")
+  end_index = SIGNUP_SHEET_HEADER.index("End")
+  event_index = SIGNUP_SHEET_HEADER.index("Event")
+
+  for row in csv_rows:
+    time = round_time(arrow.get(row[end_index], "YYYY-MM-DD HH:mm") - \
+      arrow.get(row[start_index], "YYYY-MM-DD HH:mm"))
+
+    if row[event_index] in event_hours:
+      event_hours[row[event_index]] += time
+    else:
+      event_hours[row[event_index]] = time
+
+  return event_hours
 def round_time(time):
   """
   Input: a datetime.timedelta object time.
@@ -346,7 +391,7 @@ def compute_amanuensis_data(csv_rows, low_percentage=0.1, min_days=25):
     else:
       continue
 
-    if  latest_date - earliest_date < datetime.timedelta(days=min_days):
+    if latest_date - earliest_date < datetime.timedelta(days=min_days):
       continue
 
     ta_data[ta] = (earliest_date, latest_date, hours)
